function U0 = OptMUCt(muc_t, guessN, MUs, par)

% Utilize previous solution for N efficiently as an initial guess
persistent N0 N

if isempty(N0) == 1
    N0 = guessN;
else
    N0 = N;
end

% Make sure muc_t is positive
muc_t = exp(muc_t);

MUs(:,1) = muc_t;

% - Internal Objective function
ObjFun = @(x) imperfect_ObjFun_simple(x, MUs, par);

opt_fsolve = optimoptions(@fsolve, 'Display', 'none');


try
    [N, ~, exitflag] = fsolve(ObjFun, N0, opt_fsolve);
    if exitflag ~= 1
        error('Incomplete Solution.')
    end
    
    X = imperfect_DynPath_simple(N, MUs, par);
    
    if par.chi == 1
        U0 = X.S(1)*X.Us_true(1) + X.I(1)*( X.Ui_tilde(1) );
    else
        U0 = X.S(1)*X.Us_true(1) + X.I(1)*( par.chi*X.Ui_tilde(1) + (1 - par.chi)*X.Ui_star(1) );
    end
        
catch
    U0 = -1e+15;
    N0 = [];
end

U0 = -U0;
