close all
clearvars
clc

CT = PlotColor(8, 'blue');
CT = [0.7059    0.0157    0.1490; CT];

set(groot,'defaultAxesColorOrder', CT);
set(groot,'defaultLineLineWidth', 2);
set(groot,'defaultAxesTitleFontWeight','normal');

saveflag    = 1;    % 1 to save results for each run

% Need to feed "par" containing parameter values and "MUs" containing
% containment policy and wage subsidies.

load HKK_parameters

PSIs = [0.5:0.5:4];
% PSIs = [0.4:0.3:1.6];

npsi = length(PSIs);

for i = 1:npsi+1
    spec = i;
    
    if i <= npsi
        par = par_ERT0;
        
        par.psi = PSIs(i);
        par.chi = 1;
        par.chi_bar = par.chi;
        par.kappa = 0;
        par.chi_AB = 1;
    elseif  i == npsi+1
        % SIR version
        par = par_SIR0;
        
        par.chi = 1;
        par.chi_bar = par.chi;
        par.kappa = 0;
        par.chi_AB = 1;
    end
    % Solve for the imperfect information model
    imperfect_Solve_Compact
end



varlist = {'I'; 'S'; 'R'; 'D'; 'C'; 'H'; ...
           'cs'; 'ci_tilde'; 'cr_tilde'; ...
           'ns'; 'ni_tilde'; 'nr_tilde'; ...
           'U0'};

% Packing all variables
for i = 1:length(varlist)
	eval([varlist{i} '_ALL = [];'])
	for j = 1:npsi+1
		eval([varlist{i} '_ALL = [' varlist{i} '_ALL, ' varlist{i} '_v' num2str(j) '];'])
	end
end


%% Plot and Compare the Results %%
nrows = 4;
const = 6;

% Cell array for legend labels
STR = LegendText(PSIs, '\psi');
STR2 = [STR 'SIR'];

% -- Fig 1 --
fig1 = figure;

subplot(nrows,3,1)
fh = plot([I_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Infected, I')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(nrows,3,2)
fh = plot([S_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Susceptibles, S')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(nrows,3,3)
fh = plot([R_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Recovered, R')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(nrows,3,4)
fh = plot([D_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Deaths, D')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(nrows,3,5)
fh = plot(([C_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'XLim', [0, 150])
title('Aggregate Consumption, C')
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
% Zero line
hold on
plot(zeros(par_v1.H,1), ':k', 'LineWidth', 0.5)

subplot(nrows,3,6)
fh = plot(([H_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
set(gca, 'XLim', [0, 150])
title('Aggregate Hours, H')
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
% Zero line
hold on
plot(zeros(par_v1.H,1), ':k', 'LineWidth', 0.5)

subplot(nrows,3,1+const)
fh = plot(([cs_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'YLim', [-25 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Susceptibles Consumption')

subplot(nrows,3,2+const)
fh = plot(([ci_tilde_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'YLim', [-25 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Infected Consumption')

subplot(nrows,3,3+const)
fh = plot(([cr_tilde_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'YLim', [-25 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Recovered Consumption')

subplot(nrows,3,4+const)
fh = plot(([ns_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
set(gca, 'YLim', [-25 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Susceptibles Hours')

subplot(nrows,3,5+const)
fh = plot(([ni_tilde_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
set(gca, 'YLim', [-25 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Identified Hours')

subplot(nrows,3,6+const)
fh = plot(([nr_tilde_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
set(gca, 'YLim', [-25 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Recovered Hours')

lh = legend(STR2);
set(lh, 'Location', 'SouthEast', 'EdgeColor', 'none', 'FontSize', 8)


% -- Fig 2 --
U0s = [U0_ALL(1:end-1)];
U0s_noFQ = U0s;

% save SW_noFQ U0s_noFQ

fig2 = figure;
subplot(2,1,1)

catnames = reordercats(categorical(STR),STR);
fh = bar(catnames, U0s);
set(fh, 'FaceColor', CT(2,:))
set(gca, 'YLim', [min(U0s)-0.1 max(U0s)])

grid on
ylabel('Social Welfare (U_{0})')
set(gca, 'FontSize', 11)



set(groot,'defaultAxesColorOrder', 'remove');
set(groot,'defaultLineLineWidth', 'remove')
set(groot,'defaultAxesTitleFontWeight','remove');



