close all
clearvars
clc

CT = PlotColor(5, 'blue');
set(groot,'defaultAxesColorOrder', CT);
set(groot,'defaultLineLineWidth', 2);
set(groot,'defaultAxesTitleFontWeight','normal');

saveflag    = 1;    % 1 to save results for each run

% Need to feed "par" containing parameter values and "MUs" containing
% containment policy and wage subsidies.

load HKK_parameters

PSIs = [0.4:0.3:1.6];
npsi = length(PSIs);

for i = 1:8
    spec = i;
    par = par_ERT0;
    if i <= npsi
        par.psi = PSIs(i);
        if par.psi <= 1
            par.chi = PSIs(i);
        else
            par.chi = 1;
        end
        par.chi_bar = par.chi;
        par.kappa = 0;
        par.psi_AB = 1;
    elseif i == 7
        par.chi_bar = par.chi;
        par.kappa = 0;
        par.chi_AB = 1;
    elseif i == 8
        par = par_SIR0;
        par.chi_bar = par.chi;
        par.kappa = 0;
        par.chi_AB = 1;
    end
    % Solve for the imperfect information model
    if i <= npsi
        imperfect_Solve_Compact_FQ
    elseif i >= 7
        imperfect_Solve_Compact
    end
end

varlist = {'I'; 'S'; 'R'; 'D'; 'C'; 'H'; ...
           'cs'; 'ci_tilde'; 'ci_star'; 'cr_tilde'; ...
           'ns'; 'ni_tilde'; 'ni_star'; 'nr_tilde';...
           'U0'; 'pi_dt_tilde'};

% Packing all variables
for i = 1:length(varlist)
	eval([varlist{i} '_ALL = [];'])
	for j = 1:npsi
		eval([varlist{i} '_ALL = [' varlist{i} '_ALL, ' varlist{i} '_v' num2str(j) '];'])
	end
end


%% Plot and Compare the Results %%
% -- Fig 5 --
fig1 = figure;

subplot(4,3,1)
fh = plot([I_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Infected, I')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(4,3,2)
fh = plot([S_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Susceptibles, S')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(4,3,3)
fh = plot([R_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Recovered, R')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(4,3,4)
fh = plot([D_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Deaths, D')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(4,3,5)
fh = plot(([C_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'XLim', [0, 150])
title('Aggregate Consumption, C')
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
% Zero line
hold on
plot(zeros(par_v1.H,1), ':k', 'LineWidth', 0.5)

subplot(4,3,6)
fh = plot(([H_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
set(gca, 'XLim', [0, 150])
title('Aggregate Hours, H')
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
% Zero line
hold on
plot(zeros(par_v1.H,1), ':k', 'LineWidth', 0.5)

subplot(4,3,7)
fh = plot(([cs_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'YLim', [-5 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Susceptibles Consumption')

subplot(4,3,8)
fh = plot(([ci_tilde_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'YLim', [-22 -18])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Infected Consumption')

subplot(4,3,9)
fh = plot(([cr_tilde_ALL] - par_v1.c_ss)./par_v1.c_ss*100);
box off
set(gca, 'YLim', [-22 -18])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Recovered Consumption')

subplot(4,3,10)
fh = plot(([ns_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
set(gca, 'YLim', [-5 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Susceptibles Hours')

subplot(4,3,11)
fh = plot(([ni_tilde_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
% set(gca, 'YLim', [-22 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Infected Hours')

subplot(4,3,12)
fh = plot(([nr_tilde_ALL] - par_v1.n_ss)./par_v1.n_ss*100);
box off
set(gca, 'YLim', [-4 2])
set(gca, 'XLim', [0, 150])
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
title('Recovered Hours')

STR = LegendText(PSIs, '\psi');
% STR = [STR, 'SIR'];
lh = legend(STR);
set(lh, 'Location', 'SouthEast', 'EdgeColor', 'none', 'FontSize', 8)


STR = LegendText(PSIs, '\psi');
lh = legend(STR);
set(lh, 'Location', 'SouthEast', 'EdgeColor', 'none', 'FontSize', 8)


% -- Fig 6 --
U0s = [U0_ALL];

load SW_noFQ

fig2 = figure;
subplot(2,1,1)

U0s_ALL = [U0s; U0s_noFQ];
catnames = reordercats(categorical(STR),STR);
fh = bar(catnames, U0s_ALL, 0.95);
set(fh(2), 'FaceColor',CT(4,:))
set(gca, 'YLim', [min(min(U0s_ALL))-2 max(max(U0s_ALL))])
grid on
ylabel('Social Welfare (U_{0})')
set(gca, 'FontSize', 11)

legend('With Forced Quarantine', 'No Froced Quarantine','location', 'NorthWest')

set(groot,'defaultAxesColorOrder', 'remove');
set(groot,'defaultLineLineWidth', 'remove')
set(groot,'defaultAxesTitleFontWeight','remove');



